@@ -163,9 +163,6 @@ class Horde_Memcache implements Serializable
             // Force consistent hashing
             ini_set('memcache.hash_strategy', 'consistent');
             $this->_memcache = new Memcache();
-            if (!empty($this->_params['c_threshold'])) {
-                $this->_memcache->setCompressThreshold($this->_params['c_threshold']);
-            }
         }
 
         for ($i = 0, $n = count($this->_params['hostspec']); $i < $n; ++$i) {
@@ -198,6 +195,11 @@ class Horde_Memcache implements Serializable
             throw new Horde_Memcache_Exception('Could not connect to any defined memcache servers.');
         }
 
+        if ($this->_memcache instanceof Memcache &&
+            !empty($this->_params['c_threshold'])) {
+            $this->_memcache->setCompressThreshold($this->_params['c_threshold']);
+        }
+
         if (isset($this->_params['logger'])) {
             $this->_logger = $this->_params['logger'];
             $this->_logger->log('Connected to the following memcache servers:' . implode($this->_servers, ', '), 'DEBUG');
